from enum import Enum
import typing as t

class DATA_TYPES(Enum):
    INTEGER = 1
    CHAR = 2
    VARCHAR = 3
    DECIMAL = 4
    DATE = 5

class Column():
    def __init__(self, name: str, type: DATA_TYPES, to: t.Optional[DATA_TYPES]):
        self.name = name
        self.type = type
        self.to = to

class Table():
    def __init__(self, name: str, filename: str, headers: t.List[Column]):
        self.name = name
        self.filename = filename
        self.headers = headers

TABLE_REGION = Table("REGION", "region.tbl",
[
    Column("R_REGIONKEY", DATA_TYPES.INTEGER, None),
    Column("R_NAME", DATA_TYPES.CHAR, None),
    Column("R_COMMENT", DATA_TYPES.VARCHAR, None),
])                            

TABLE_NATION = Table("NATION", "nation.tbl",
    [
        Column("N_NATIONKEY", DATA_TYPES.INTEGER, None),
        Column("N_NAME", DATA_TYPES.CHAR, None),
        Column("N_REGIONKEY", DATA_TYPES.INTEGER, None),
        Column("N_COMMENT", DATA_TYPES.VARCHAR, None),
    ]
)

TABLE_PART = Table("PART", "part.tbl", [ 
    Column("P_PARTKEY", DATA_TYPES.INTEGER, None),
    Column("P_NAME", DATA_TYPES.VARCHAR, None),
    Column("P_MFGR", DATA_TYPES.CHAR, None),
    Column("P_BRAND", DATA_TYPES.CHAR, None),
    Column("P_TYPE", DATA_TYPES.VARCHAR, None),
    Column("P_SIZE", DATA_TYPES.INTEGER, None),
    Column("P_CONTAINER", DATA_TYPES.CHAR, None),
    Column("P_RETAILPRICE", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("P_COMMENT", DATA_TYPES.VARCHAR, None),
])
TABLE_SUPPLIER = Table("SUPPLIER", "supplier.tbl", [ 
    Column("S_SUPPKEY", DATA_TYPES.INTEGER, None),
    Column("S_NAME", DATA_TYPES.CHAR, None),
    Column("S_ADDRESS", DATA_TYPES.VARCHAR, None),
    Column("S_NATIONKEY", DATA_TYPES.INTEGER, None),
    Column("S_PHONE", DATA_TYPES.CHAR, None),
    Column("S_ACCTBAL", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("S_COMMENT", DATA_TYPES.VARCHAR, None),
])
TABLE_PARTSUPP = Table("PARTSUPP", "partsupp.tbl", [ 
    Column("PS_PARTKEY", DATA_TYPES.INTEGER, None),
    Column("PS_SUPPKEY", DATA_TYPES.INTEGER, None),
    Column("PS_AVAILQTY", DATA_TYPES.INTEGER, None),
    Column("PS_SUPPLYCOST", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("PS_COMMENT", DATA_TYPES.VARCHAR, None),
])
TABLE_CUSTOMER = Table("CUSTOMER", "customer.tbl", [ 
    Column("C_CUSTKEY", DATA_TYPES.INTEGER, None),
    Column("C_NAME", DATA_TYPES.VARCHAR, None),
    Column("C_ADDRESS", DATA_TYPES.VARCHAR, None),
    Column("C_NATIONKEY", DATA_TYPES.INTEGER, None),
    Column("C_PHONE", DATA_TYPES.CHAR, None),
    Column("C_ACCTBAL", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("C_MKTSEGMENT", DATA_TYPES.CHAR, None),
    Column("C_COMMENT", DATA_TYPES.VARCHAR, None),
])
TABLE_ORDERS = Table("ORDERS", "orders.tbl", [ 
    Column("O_ORDERKEY", DATA_TYPES.INTEGER, None),
    Column("O_CUSTKEY", DATA_TYPES.INTEGER, None),
    Column("O_ORDERSTATUS", DATA_TYPES.CHAR, None),
    Column("O_TOTALPRICE", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("O_ORDERDATE", DATA_TYPES.DATE, None),
    Column("O_ORDERPRIORITY", DATA_TYPES.CHAR, None),
    Column("O_CLERK", DATA_TYPES.CHAR, None),
    Column("O_SHIPPRIORITY", DATA_TYPES.INTEGER, None),
    Column("O_COMMENT", DATA_TYPES.VARCHAR, None),
])

TABLE_LINEITEM = Table("LINEITEM", "lineitem.tbl", [      
    Column("L_ORDERKEY", DATA_TYPES.INTEGER, None),
    Column("L_PARTKEY", DATA_TYPES.INTEGER, None),
    Column("L_SUPPKEY", DATA_TYPES.INTEGER, None),
    Column("L_LINENUMBER", DATA_TYPES.INTEGER, None),
    Column("L_QUANTITY", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("L_EXTENDEDPRICE", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("L_DISCOUNT", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("L_TAX", DATA_TYPES.DECIMAL, DATA_TYPES.INTEGER),
    Column("L_RETURNFLAG", DATA_TYPES.CHAR, None),
    Column("L_LINESTATUS", DATA_TYPES.CHAR, None),
    Column("L_SHIPDATE", DATA_TYPES.DATE, DATA_TYPES.INTEGER),
    Column("L_COMMITDATE", DATA_TYPES.DATE, DATA_TYPES.INTEGER),
    Column("L_RECEIPTDATE", DATA_TYPES.DATE, DATA_TYPES.INTEGER),
    Column("L_SHIPINSTRUCT", DATA_TYPES.CHAR, None),
    Column("L_SHIPMODE", DATA_TYPES.CHAR, None),
    Column("L_COMMENT", DATA_TYPES.VARCHAR, None),
])

TABLES: t.List[Table] = [TABLE_REGION, TABLE_CUSTOMER, TABLE_NATION, TABLE_LINEITEM, TABLE_ORDERS, TABLE_PART, TABLE_PARTSUPP, TABLE_SUPPLIER]
